<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\AdminProfileRequest;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Auth;
use App\Models\Admin;
use App\Models\Role;
use App\Models\Post;
use App\Models\PostCategoryRelationship;
use App\Models\PostMeta;
use App\Models\ContactForm;
use App\Models\AppoinmentRequest;
use Session;
use File;

class AdminController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth:admin');

    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $cat_id = 2;
        $pages = Post::where([['post_type', 'page'],['status',1]])->orderBy('created_at', 'desc')->get();
        $contact_req = ContactForm::count();
        $appo_req = AppoinmentRequest::count();
        $posts = Post::whereHas('categories', function($query) use($cat_id) {
                    $query->where('category_id','=',$cat_id);
            })->where([['post_type', 'post'],['status',1]])->get();
            
        $latest_blogs = Post::whereHas('categories', function($query) use($cat_id) {
                    $query->where('category_id','=',$cat_id);
            })->where([['post_type', 'post'],['status',1]])->orderBy('created_at', 'desc')->take(10)->get();
            
        $latest_pages = Post::where([['post_type', 'page'],['status',1]])->orderBy('created_at', 'desc')->take(10)->get();
        
        $latest_appo = AppoinmentRequest::orderBy('created_at', 'desc')->take(10)->get();
        
        return view('admin.dashboard',compact('pages','posts','contact_req','appo_req','latest_blogs','latest_pages','latest_appo'));
    }

    public function profile(AdminProfileRequest $request)
    {
        if ($request->isMethod('PATCH')) {
            $input = $request->all();
            $profile = Admin::where('id',Auth::guard('admin')->user()->id)->firstOrFail();
                /*if($request->hasFile('image'))
                {
                    $destinationPath = 'uploads';
                    $file = $request->file('image');
                    $original_name = pathinfo($file->getClientOriginalName(), PATHINFO_FILENAME);
                    $extension = $file->getClientOriginalExtension();
                    $filename=time().rand(100,999).$original_name.'.'.$extension;
                    
                    $file->move(
                        config('services.new_root_path').$destinationPath, $filename
                    );

                    $input['image'] = $filename;

                    if ($profile->image) {
                            
                            File::delete(config('services.new_root_path').'uploads/'.$profile->image);
                        }
                }*/
            $result = $profile->update($input);
            if( $profile->roles->contains(1) ){ // Super Admin only can change the Roles 

                $profile->roles()->sync($input['role']);

            }
            if($result){
               Session::flash('success', 'Admin profile updated successfully'); 
            } else {
               Session::flash('danger', 'Error encounterd');
            }
               return redirect()->route('admin.profile');
            } else {
            $profile = Admin::where('id',Auth::guard('admin')->user()->id)->firstOrFail();
            $roles = Role::where('guard_name','admin')->pluck('name','id')->toArray();
            $user_roles = $profile->roles;
            return view('admin.profile.edit',compact('profile','roles','user_roles'));
        }
        
    }

    public function change_password(AdminProfileRequest $request)
    {
       if ($request->isMethod('PATCH')) {
            $user = Admin::where('id',Auth::guard('admin')->user()->id)->firstOrFail();
            $check = Hash::check($request->old_password, $user->password);
            if($check){
                $user->password = Hash::make($request->input('password'));
                $result = $user->update();
                if($result){
                   Session::flash('success', 'Admin password updated Successfully'); 
                } else {
                   Session::flash('danger', 'Error Encounterd');
                }
             } else{
                Session::flash('warning', 'Your current password is not mathching'); 
             }
             return redirect()->route('admin.change_password');
        }else {
            $user = Admin::where('id',Auth::guard('admin')->user()->id)->firstOrFail();
            return view('admin.profile.edit',compact('user'));
        }
        
    }
}
